Module errors

Module errors 

Contains all the errors that can be returned by the library.

Structs

ApiError
An error received when an API request fails.
JsonError
Data about the specific error encountered, returned as JSON by the API.
JsonErrorKey
A JSON key mirroring one in the request schema, with detailed error keys (JsonErrorKeyError)
JsonErrorKeyError
A more specific error given for a JSON schema key.

Enums

ChorusError
GatewayError
For errors we receive from the gateway, see https://docs.discord.food/topics/opcodes-and-status-codes#gateway-close-event-codes;
ObserverError
RegistrationError
VoiceGatewayError
Voice Gateway errors
VoiceUdpError
Voice UDP errors.

Type Aliases

ChorusResult