GuildDiscoveryRequirements

Struct GuildDiscoveryRequirements 

pub struct GuildDiscoveryRequirements {
Show 17 fields pub guild_id: Option<Snowflake>, pub safe_environment: Option<bool>, pub healthy: Option<bool>, pub health_score_pending: Option<bool>, pub size: Option<bool>, pub nsfw_properties: Option<GuildDiscoveryNsfwProperties>, pub protected: Option<bool>, pub sufficient: Option<bool>, pub sufficient_without_grace_period: Option<bool>, pub valid_rules_channel: Option<bool>, pub retention_healthy: Option<bool>, pub engagement_healthy: Option<bool>, pub age: Option<bool>, pub minimum_age: Option<u16>, pub health_score: Option<GuildDiscoveryHealthScore>, pub minimum_size: Option<u64>, pub grace_period_end_date: Option<DateTime<Utc>>,
}
A guild’s progress on meeting the requirements of joining discovery.

Certain guilds, such as those that are verified, are exempt from discovery requirements. These guilds will not have a fully populated discovery requirements object, and are guaranteed to receive only sufficient and sufficient_without_grace_period.

Reference

See https://docs.discord.food/resources/discovery#discovery-requirements-object

Fields

guild_id: Option<Snowflake>safe_environment: Option<bool>healthy: Option<bool>health_score_pending: Option<bool>size: Option<bool>nsfw_properties: Option<GuildDiscoveryNsfwProperties>protected: Option<bool>sufficient: Option<bool>sufficient_without_grace_period: Option<bool>valid_rules_channel: Option<bool>retention_healthy: Option<bool>engagement_healthy: Option<bool>age: Option<bool>minimum_age: Option<u16>health_score: Option<GuildDiscoveryHealthScore>minimum_size: Option<u64>grace_period_end_date: Option<DateTime<Utc>>