GuildMember

Struct GuildMember 

pub struct GuildMember {
    pub user: Option<Shared<PublicUser>>,
    pub nick: Option<String>,
    pub avatar: Option<String>,
    pub roles: Vec<Snowflake>,
    pub joined_at: DateTime<Utc>,
    pub premium_since: Option<DateTime<Utc>>,
    pub deaf: bool,
    pub mute: bool,
    pub flags: Option<GuildMemberFlags>,
    pub pending: Option<bool>,
    pub permissions: PermissionFlags,
    pub communication_disabled_until: Option<DateTime<Utc>>,
}
Represents a participating user in a guild.

Reference

See https://docs.discord.food/resources/guild#guild-member-object

Fields

user: Option<Shared<PublicUser>>nick: Option<String>avatar: Option<String>roles: Vec<Snowflake>joined_at: DateTime<Utc>premium_since: Option<DateTime<Utc>>deaf: boolmute: boolflags: Option<GuildMemberFlags>pending: Option<bool>permissions: PermissionFlagscommunication_disabled_until: Option<DateTime<Utc>>

Implementations

Source

impl GuildMember

pub async fn get( user: &mut ChorusUser, guild_id: Snowflake, member_id: Snowflake, ) -> ChorusResult<GuildMember>

Fetch a GuildMember object for the specified user.

Notes

This is an alias of Guild::get_member

Reference

See https://docs.discord.food/resources/guild#get-guild-member

pub async fn add( guild_id: Snowflake, user_id: Snowflake, schema: AddGuildMemberSchema, user: &mut ChorusUser, ) -> ChorusResult<AddGuildMemberReturn>

Adds a user to a guild, provided you have a valid OAuth2 access token for that user with the guilds.join scope.

This endpoint is only usable by bots, they must be belonging to the application used for authorization and they must be a member of the guild with the CREATE_INSTANT_INVITE permission.

Notes

This is an alias of Guild::add_member

Reference

See https://docs.discord.food/resources/guild#add-guild-member

pub async fn remove( guild_id: Snowflake, member_id: Snowflake, audit_log_reason: Option<String>, user: &mut ChorusUser, ) -> ChorusResult<()>

Removes a GuildMember from a guild.

Requires the KICK_MEMBERS permission.

Notes

This is an alias of Guild::remove_member

Reference

See https://docs.discord.food/resources/guild#remove-guild-member

pub async fn modify( guild_id: Snowflake, member_id: Snowflake, schema: ModifyGuildMemberSchema, audit_log_reason: Option<String>, user: &mut ChorusUser, ) -> ChorusResult<GuildMember>

Modifies a GuildMember object.

Returns the updated object on success.

Notes

This is an alias of Guild::modify_member

Reference

https://docs.discord.food/resources/guild#modify-guild-member

pub async fn modify_current( guild_id: Snowflake, schema: ModifyCurrentGuildMemberSchema, audit_log_reason: Option<String>, user: &mut ChorusUser, ) -> ChorusResult<GuildMember>

Modifies the current user’s member object in the guild.

Notes

This is an alias of Guild::modify_current_member

Reference

See https://docs.discord.food/resources/guild#modify-current-guild-member

pub async fn modify_current_profile( guild_id: Snowflake, schema: ModifyGuildMemberProfileSchema, user: &mut ChorusUser, ) -> ChorusResult<UserProfileMetadata>

Modifies the current user’s profile in the guild.

Notes

This is an alias of Guild::modify_current_member_profile

Reference

See https://docs.discord.food/resources/guild#modify-guild-member-profile

pub async fn add_role( user: &mut ChorusUser, audit_log_reason: Option<String>, guild_id: Snowflake, member_id: Snowflake, role_id: Snowflake, ) -> ChorusResult<()>

Adds a role to a guild member.

Requires the MANAGE_ROLES permission.

Notes

This is an alias of Guild::add_member_role

Reference

See https://docs.discord.food/resources/guild#add-guild-member-role

pub async fn remove_role( user: &mut ChorusUser, audit_log_reason: Option<String>, guild_id: Snowflake, member_id: Snowflake, role_id: Snowflake, ) -> Result<(), ChorusError>

Removes a role from a guild member.

Requires the MANAGE_ROLES permission.

Notes

This is an alias of Guild::remove_member_role

Reference

See https://docs.discord.food/resources/guild#remove-guild-member-role