pub struct RecentMentionDelete {
pub message_id: Snowflake,
}Expand description
Sent when a message that mentioned the current user in the last week is acknowledged and deleted.
Reference
See https://docs.discord.food/topics/gateway-events#recent-mention-delete
Fields
message_id: SnowflakeTrait Implementations
Sourceimpl Clone for RecentMentionDelete
impl Clone for RecentMentionDelete
Sourcefn clone(&self) -> RecentMentionDelete
fn clone(&self) -> RecentMentionDelete
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecentMentionDelete
impl Debug for RecentMentionDelete
Sourceimpl Default for RecentMentionDelete
impl Default for RecentMentionDelete
Sourcefn default() -> RecentMentionDelete
fn default() -> RecentMentionDelete
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RecentMentionDelete
impl<'de> Deserialize<'de> for RecentMentionDelete
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for RecentMentionDelete
impl Serialize for RecentMentionDelete
impl Copy for RecentMentionDelete
impl WebSocketEvent for RecentMentionDelete