Contains all the errors that can be returned by the library.
Structs
- ApiError
- An error received when an API request fails.
- Json
Error - Data about the specific error encountered, returned as JSON by the API.
- Json
Error Key - A JSON key mirroring one in the request schema, with detailed error keys (JsonErrorKeyError)
- Json
Error KeyError - A more specific error given for a JSON schema key.
Enums
- Chorus
Error - Gateway
Error - For errors we receive from the gateway, see https://docs.discord.food/topics/opcodes-and-status-codes#gateway-close-event-codes;
- Observer
Error - Registration
Error - Voice
Gateway Error - Voice Gateway errors
- Voice
UdpError - Voice UDP errors.