pub struct GatewayCapabilities(/* private fields */);Expand description
Implementations
Sourceimpl GatewayCapabilities
impl GatewayCapabilities
Sourcepub const LAZY_USER_NOTES: Self
pub const LAZY_USER_NOTES: Self
Removes the notes field from the Ready event,
Sourcepub const NO_AFFINE_USER_IDS: Self
pub const NO_AFFINE_USER_IDS: Self
Prevents member/presence syncing and Presence Update events for implicit relationships
Sourcepub const VERSIONED_READ_STATES: Self
pub const VERSIONED_READ_STATES: Self
Enables versioned read states, changing the read_state field in the Ready event to an object, allowing it to be cached when re-identifying
Sourcepub const VERSIONED_USER_GUILD_SETTINGS: Self
pub const VERSIONED_USER_GUILD_SETTINGS: Self
Enables versioned user guild settings, changing the user_guild_settings field in the Ready event to an object, allowing it to be cached when re-identifying
Sourcepub const DEDUPE_USER_OBJECTS: Self
pub const DEDUPE_USER_OBJECTS: Self
Dehydrates the Ready payload, moving all user objects to the users field and replacing them in various places in the payload with user_id or recipient_id, and merging the members fields of all guilds into a single merged_members field
Sourcepub const PRIORITIZED_READY_PAYLOAD: Self
pub const PRIORITIZED_READY_PAYLOAD: Self
1 Separates the Ready payload into two parts (Ready and Ready Supplemental) allowing the client to receive the Ready payload faster and then receive the rest of the payload later
Sourcepub const MULTIPLE_GUILD_EXPERIMENT_POPULATIONS: Self
pub const MULTIPLE_GUILD_EXPERIMENT_POPULATIONS: Self
Changes the populations entry of guild_experiments in the Ready event to be an array of populations rather than a single population
Sourcepub const NON_CHANNEL_READ_STATES: Self
pub const NON_CHANNEL_READ_STATES: Self
Includes read states tied to non-channel resources (e.g. guild scheduled events and notification center) in the read_states field of the Ready event
Sourcepub const AUTH_TOKEN_REFRESH: Self
pub const AUTH_TOKEN_REFRESH: Self
Enables auth token refresh, allowing the client to optionally receive a new auth token in the auth_token field of the Ready event
Sourcepub const USER_SETTINGS_PROTO: Self
pub const USER_SETTINGS_PROTO: Self
Removes the user_settings field from the Ready event, and prevents User Settings Update events; the user_settings_proto field and User Settings Proto Update event is used instead
Sourcepub const CLIENT_STATE_V2: Self
pub const CLIENT_STATE_V2: Self
Enables client state caching v2
Sourcepub const PASSIVE_GUILD_UPDATE: Self
pub const PASSIVE_GUILD_UPDATE: Self
Enables passive guild updates, allowing the client to receive Passive Update v1 events instead of Channel Unreads Update events for guilds it is not subscribed to
Sourcepub const AUTO_CALL_CONNECT: Self
pub const AUTO_CALL_CONNECT: Self
Connects the client to all pre-existing calls upon connecting to the Gateway; this means clients will receive Call Create events for all calls created before the Gateway connection was established without needing to send a Request Call Connect first
Sourcepub const DEBOUNCE_MESSAGE_REACTIONS: Self
pub const DEBOUNCE_MESSAGE_REACTIONS: Self
Debounces message reaction events, preventing the client from receiving multiple Message Reaction Add events for the same message within a short period of time; clients will receive a single Message Reaction Add Many event instead
Sourcepub const PASSIVE_GUILD_UPDATE_V2: Self
pub const PASSIVE_GUILD_UPDATE_V2: Self
Enables passive guild updates v2, allowing the client to receive Passive Update v2 events instead of Channel Unreads Update events for guilds it is not subscribed to
Sourceimpl GatewayCapabilities
impl GatewayCapabilities
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl GatewayCapabilities
impl GatewayCapabilities
Sourcepub const fn iter(&self) -> Iter<GatewayCapabilities>
pub const fn iter(&self) -> Iter<GatewayCapabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<GatewayCapabilities>
pub const fn iter_names(&self) -> IterNames<GatewayCapabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.