pub struct PremiumUsage {
pub nitro_sticker_sends: PremiumUsageData,
pub total_animated_emojis: PremiumUsageData,
pub total_global_emojis: PremiumUsageData,
pub total_large_uploads: PremiumUsageData,
pub total_hd_streams: PremiumUsageData,
pub hd_hours_streamed: PremiumUsageData,
}Expand description
Structure which defines the local user’s premium perk usage.
Reference
See https://docs.discord.food/resources/user#get-user-premium-usage
Fields
nitro_sticker_sends: PremiumUsageDataNumber of Nitro stickers the user has sent
total_animated_emojis: PremiumUsageDataNumber of animated emojis the user has sent
total_global_emojis: PremiumUsageDataNumber of global emojis the user has sent
total_large_uploads: PremiumUsageDataNumber of large uploads the user has made
total_hd_streams: PremiumUsageDataNumber of times the user has streamed in HD
hd_hours_streamed: PremiumUsageDataNumber of hours the user has streamed in HD